RecoveryResult

Enum RecoveryResult 

pub enum RecoveryResult {
    Recovered(usize),
    AtSyncPoint,
    BudgetExhausted,
    ReachedEof,
}
Result of an error recovery attempt. Result of a recovery operation.

Variants



Recovered(usize)

Recovery succeeded, consumed the given number of tokens.



AtSyncPoint

Already at a sync point when recovery was called. The caller must decide whether to consume the sync token. This prevents infinite loops at call boundaries.



BudgetExhausted

Recovery failed due to budget exhaustion.



ReachedEof

Recovery reached EOF without finding sync point.