CompileEnvironmentBoundaryKind

Enum CompileEnvironmentBoundaryKind 

#[non_exhaustive]
pub enum CompileEnvironmentBoundaryKind { DynamicRequire, DynamicPragmaArgs, DynamicIncRoot, PhaseBlockExecution, SymbolicReferenceDeref, }
Dynamic compile-environment boundary category.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DynamicRequire

require target could not be determined statically.



DynamicPragmaArgs

Pragma or feature arguments could not be determined statically.



DynamicIncRoot

Include-root effect is dynamic or unsupported.



PhaseBlockExecution

Phase block contains compile-time execution that is not evaluated here.



SymbolicReferenceDeref

Symbolic-reference dereference is possible while strict refs is disabled.