HirKind

Enum HirKind 

#[non_exhaustive]
pub enum HirKind {
Show 13 variants PackageDecl(PackageDecl), SubDecl(SubDecl), MethodDecl(MethodDecl), UseDecl(UseDecl), RequireDecl(RequireDecl), VariableDecl(VariableDecl), CallExpr(CallExpr), MethodCallExpr(MethodCallExpr), IndirectCallExpr(IndirectCallExpr), BarewordExpr(BarewordExpr), LiteralExpr(LiteralExpr), BlockShell(BlockShell), DynamicBoundary(DynamicBoundary),
}
First-slice HIR constructs.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PackageDecl(PackageDecl)

package Foo; or block package declaration.



SubDecl(SubDecl)

sub foo { ... } declaration.



MethodDecl(MethodDecl)

method foo { ... } declaration.



UseDecl(UseDecl)

use Module ...; declaration.



RequireDecl(RequireDecl)

require Module; call recognized as a compile-time declaration shape.



VariableDecl(VariableDecl)

my, our, state, or local variable declaration.



CallExpr(CallExpr)

Function-like call expression shell.



MethodCallExpr(MethodCallExpr)

Method-call expression shell.



IndirectCallExpr(IndirectCallExpr)

Indirect-object method-call expression shell.



BarewordExpr(BarewordExpr)

Bareword expression shell.



LiteralExpr(LiteralExpr)

Literal expression shell.



BlockShell(BlockShell)

Block expression shell without scope construction.



DynamicBoundary(DynamicBoundary)

Unsupported or intentionally dynamic Perl boundary.

Implementations

Source

impl HirKind

pub const ALL_KIND_NAMES: &[&'static str]

Canonical names for all first-slice HIR construct variants.

Metrics and status generators should use this list instead of keeping a separate copy of the current HIR surface.