#[non_exhaustive]pub enum ModuleResolutionStatus {
Deferred,
Dynamic,
}Expand description
Static module-resolution status.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Deferred
Static module target was recorded, but path resolution is intentionally deferred.
Dynamic
Module target is dynamic and cannot be resolved statically.