#[non_exhaustive]pub struct GlobSlot {
pub name: String,
pub kind: GlobSlotKind,
pub range: SourceLocation,
pub declaration_item: Option<HirId>,
pub source: GlobSlotSource,
pub alias_target: Option<String>,
pub provenance: StashProvenance,
pub confidence: StashConfidence,
}Expand description
One slot inside a Perl typeglob.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringSymbol name without sigil.
kind: GlobSlotKindSlot category.
range: SourceLocationSource range for the declaration or mutation that produced this slot.
declaration_item: Option<HirId>HIR item that produced this slot, when available.
source: GlobSlotSourceSource shape that produced this slot.
alias_target: Option<String>Static alias target, when this slot is an alias.
provenance: StashProvenanceHow this slot fact was produced.
confidence: StashConfidenceConfidence in this slot fact.