PragmaEffect

Struct PragmaEffect 

#[non_exhaustive]
pub struct PragmaEffect { pub pragma: String, pub enabled: bool, pub args: Vec<String>, pub argument_kind: PragmaArgumentKind, pub range: SourceLocation, pub directive_item: Option<HirId>, pub scope_id: Option<HirScopeId>, pub package_context: Option<String>, pub provenance: CompileProvenance, pub confidence: CompileConfidence, }
Pragma or feature state change.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
pragma: String

Pragma name.

enabled: bool

Whether the pragma is being enabled (use) or disabled (no).

args: Vec<String>

Static, normalized categories or feature names captured by the parser.

argument_kind: PragmaArgumentKind

Whether this effect applies broadly or to listed categories/features.

range: SourceLocation

Source range for the effect.

directive_item: Option<HirId>

Directive that produced this effect.

scope_id: Option<HirScopeId>

Scope containing the effect.

package_context: Option<String>

Package context active at the effect.

provenance: CompileProvenance

How this fact was produced.

confidence: CompileConfidence

Confidence in this fact.