PragmaStateFact

Struct PragmaStateFact 

#[non_exhaustive]
pub struct PragmaStateFact {
Show 13 fields pub range: SourceLocation, pub anchor_id: AnchorId, pub directive_item: Option<HirId>, pub scope_id: Option<HirScopeId>, pub package_context: Option<String>, pub strict_vars: bool, pub strict_subs: bool, pub strict_refs: bool, pub warnings: bool, pub disabled_warning_categories: Vec<String>, pub features: Vec<String>, pub provenance: CompileProvenance, pub confidence: CompileConfidence,
}
Effective strict/warnings/feature state after a compile-time transition.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
range: SourceLocation

Source range for the transition that produced this state.

anchor_id: AnchorId

Stable source anchor for this transition.

directive_item: Option<HirId>

Directive that produced this state, when HIR has one.

scope_id: Option<HirScopeId>

Scope containing this transition.

package_context: Option<String>

Package context active at this transition.

strict_vars: bool

Effective strict vars state.

strict_subs: bool

Effective strict subs state.

strict_refs: bool

Effective strict refs state.

warnings: bool

Effective global warnings state.

disabled_warning_categories: Vec<String>

Warning categories explicitly disabled in this state.

features: Vec<String>

Effective feature names in this state.

provenance: CompileProvenance

How this fact was produced.

confidence: CompileConfidence

Confidence in this fact.

Implementations

Source

impl PragmaStateFact

pub fn strict_enabled(&self) -> bool

Whether all strict categories are active in this state.

pub fn warning_active(&self, category: &str) -> bool

Whether warnings are active for a category in this state.

pub fn has_feature(&self, feature: &str) -> bool

Whether a feature is active in this state.