ScopeGraph

Struct ScopeGraph 

#[non_exhaustive]
pub struct ScopeGraph { pub scopes: Vec<ScopeFrame>, pub bindings: Vec<Binding>, pub references: Vec<BindingReference>, }
HIR-local scope graph for compiler-substrate proof.

The graph is intentionally parser-core-local. Later compiler fact export can map these ids to perl-semantic-facts ids without changing provider behavior in this first scope/pad slice.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
scopes: Vec<ScopeFrame>

Scope frames in stable creation order.

bindings: Vec<Binding>

Bindings in stable declaration order.

references: Vec<BindingReference>

Variable references observed while lowering.

Implementations

Source

impl ScopeGraph

pub fn root_scope(&self) -> Option<&ScopeFrame>

Return the root file scope, when present.