PirContext

Enum PirContext 

#[non_exhaustive]
pub enum PirContext { Scalar, List, Void, Lvalue, Unknown, }
Expression context modeled by PIR v0.

Unknown context is allowed when the compiler substrate cannot prove context without executing Perl. Unknown context is visible in receipts and is never silently promoted to scalar or list.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Scalar

Scalar context.



List

List context.



Void

Void context.



Lvalue

Lvalue (assignment-target) context.



Unknown

Context that cannot be proven statically.

Implementations

Source

impl PirContext

pub const fn name(self) -> &'static str

Stable name used in receipts and snapshots.