#[non_exhaustive]pub enum PirEdgeKind {
Fallthrough,
Branch,
Loop,
Return,
DynamicExit,
Unknown,
}Expand description
Control-flow edge category.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fallthrough
Straight-line fallthrough to the next node in the same region.
Branch
Edge taken by a branch arm.
Loop
Edge taken by a loop back-edge or entry.
Return
Edge taken by a return.
DynamicExit
Edge leaving the modeled graph through a dynamic boundary.
Unknown
Conservative unknown edge that must not be dropped silently.
Implementations