#[non_exhaustive]pub struct PirId { /* private fields */ }Expand description
Stable identifier for a PIR node within one lowering receipt.
IDs are internally deterministic for the same source, compiler environment, and configuration. They are not guaranteed stable across versions or unrelated workspaces.
Implementations