Module edit

Module edit 

Edit tracking for incremental parsing (previously perl-edit). Edit tracking for incremental parsing

This module provides types and algorithms for tracking edits to source code and applying them to an existing parse tree.

Structs

Edit
Represents an edit to the source text
EditSet
Collection of edits that can be applied together