#[non_exhaustive]pub enum DynamicBoundaryKind {
CoderefCall,
EvalExpression,
DoExpression,
DynamicStashMutation,
Autoload,
SymbolicReferenceDeref,
}Expand description
Dynamic-boundary category.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CoderefCall
Coderef/dynamic callee call through ->().
EvalExpression
eval whose body is not a statically parsed block.
DoExpression
do whose body is not a statically parsed block.
DynamicStashMutation
Stash/typeglob assignment whose effect cannot be modeled statically.
Autoload
AUTOLOAD declaration introduces dynamic method dispatch.
SymbolicReferenceDeref
Symbolic-reference dereference whose target cannot be modeled statically.